@@ -1,10 +1,13 @@
 import os
 import sys
+from typing import List
 from uuid import uuid4
 
 from dateutil.relativedelta import relativedelta
 from django import VERSION
+from django.db.backends.signals import connection_created
 from edc_utils import get_utcnow
+from edc_utils.sqlite import activate_foreign_keys
 
 from .default_installed_apps import DEFAULT_EDC_INSTALLED_APPS
 
@@ -54,6 +57,7 @@ class DefaultTestSettings:
         **kwargs,
     ):
 
+        connection_created.connect(activate_foreign_keys)
         self.calling_file = os.path.basename(calling_file) if calling_file else None
         self.base_dir = base_dir or kwargs.get("BASE_DIR")
         self.app_name = app_name or kwargs.get("APP_NAME")
@@ -94,6 +98,8 @@ class DefaultTestSettings:
                 [
                     "edc_dashboard.middleware.DashboardMiddleware",
                     "edc_subject_dashboard.middleware.DashboardMiddleware",
+                    "edc_listboard.middleware.DashboardMiddleware",
+                    "edc_review_dashboard.middleware.DashboardMiddleware",
                 ]
             )
 
@@ -118,8 +124,33 @@ class DefaultTestSettings:
             else:
                 self.settings.update(ROOT_URLCONF=f"{self.app_name}.urls")
 
+    @property
+    def default_context_processors(self) -> List[str]:
+        return [
+            "django.contrib.auth.context_processors.auth",
+            "django.contrib.messages.context_processors.messages",
+            "django.template.context_processors.request",
+        ]
+
+    @property
+    def edc_context_processors(self) -> List[str]:
+        context_processors = []
+        if [a for a in self.installed_apps if a.startswith("edc_model_admin")]:
+            context_processors.append("edc_model_admin.context_processors.admin_theme")
+        if [a for a in self.installed_apps if a.startswith("edc_constants")]:
+            context_processors.append("edc_constants.context_processors.constants")
+        if [a for a in self.installed_apps if a.startswith("edc_appointment")]:
+            context_processors.append("edc_appointment.context_processors.constants")
+        if [a for a in self.installed_apps if a.startswith("edc_visit_tracking")]:
+            context_processors.append("edc_visit_tracking.context_processors.constants")
+        return context_processors
+
     def _update_defaults(self):
         """Assumes BASE_DIR, APP_NAME are in kwargs."""
+
+        context_processors = self.default_context_processors
+        context_processors.extend(self.edc_context_processors)
+
         self.settings.update(
             ALLOWED_HOSTS=["localhost"],
             STATIC_URL="/static/",
@@ -138,14 +169,7 @@ class DefaultTestSettings:
                 {
                     "BACKEND": "django.template.backends.django.DjangoTemplates",
                     "APP_DIRS": True,
-                    "OPTIONS": {
-                        "context_processors": [
-                            "django.contrib.auth.context_processors.auth",
-                            "django.contrib.messages.context_processors.messages",
-                            "django.template.context_processors.request",
-                            "edc_model_admin.context_processors.admin_theme",
-                        ]
-                    },
+                    "OPTIONS": {"context_processors": context_processors},
                 }
             ],
             MIDDLEWARE=[
